# `Nefertari`
[![Build Status](https://travis-ci.org/ramses-tech/nefertari.svg?branch=master)](https://travis-ci.org/ramses-tech/nefertari)
[![Documentation](https://readthedocs.org/projects/nefertari/badge/?version=stable)](http://nefertari.readthedocs.org)

Nefertari is a REST API framework sitting on top of [Pyramid](https://github.com/Pylons/pyramid) and [Elasticsearch](https://www.elastic.co/downloads/elasticsearch). She currently offers two backend engines: [SQLA](https://github.com/ramses-tech/nefertari-sqla) and [MongoDB](https://github.com/ramses-tech/nefertari-mongodb).
